@@ -630,19 +630,24 @@ class Notebook:
             return
         #
         has_error = False
+        errors = []
         for output in outputs:
             try:
                 errors = output.find_element_by_css_selector('.output_stderr')
-                if errors:
-                    if expect_error:
-                        has_error = True
-                    else:
-                        raise ValueError(
-                            f'Cell produces error message: {errors.text}. Use expect_error=True to suppress this error if needed.'
-                        )
             except NoSuchElementException:
                 # if no error, ok
-                pass
+                try:
+                    errors = output.find_element_by_css_selector('.output_error')
+                except NoSuchElementException:
+                    pass
+        if errors:
+            if expect_error:
+                has_error = True
+            else:
+                raise ValueError(
+                    f'Cell produces error message: {errors.text}. Use expect_error=True to suppress this error if needed.'
+                )
+
         #
         if expect_error and not has_error:
             raise ValueError(
